package com.fastbee.data.controller.waterele;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.fastbee.waterele.domain.MaGuangaiRecord;
import com.fastbee.waterele.service.IMaGuangaiRecordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 灌溉记录Controller
 *
 * @author kerwincui
 * @date 2024-08-12
 */
@RestController
@RequestMapping("/waterele/guangaiRecord")
@Api(tags = "灌溉记录")
public class MaGuangaiRecordController extends BaseController
{
    @Autowired
    private IMaGuangaiRecordService maGuangaiRecordService;

/**
 * 查询灌溉记录列表
 */
@PreAuthorize("@ss.hasPermi('waterele:guangaiRecord:list')")
@GetMapping("/list")
@ApiOperation("查询灌溉记录列表")
    public TableDataInfo list(MaGuangaiRecord maGuangaiRecord)
    {
//        startPage();
        TableDataInfo tableDataInfo
                = maGuangaiRecordService.selectMaGuangaiRecordList(maGuangaiRecord);
        return tableDataInfo;
    }

    /**
     * 导出灌溉记录列表
     */
    @ApiOperation("导出灌溉记录列表")
    @PreAuthorize("@ss.hasPermi('waterele:guangaiRecord:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MaGuangaiRecord maGuangaiRecord)
    {
        TableDataInfo tableDataInfo = maGuangaiRecordService.selectMaGuangaiRecordList(maGuangaiRecord);
        List<MaGuangaiRecord> list = (List<MaGuangaiRecord>) tableDataInfo.getRows();
        ExcelUtil<MaGuangaiRecord> util = new ExcelUtil<MaGuangaiRecord>(MaGuangaiRecord.class);
        util.exportExcel(response, list, "灌溉记录数据");
    }

    /**
     * 获取灌溉记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('waterele:guangaiRecord:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取灌溉记录详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(maGuangaiRecordService.selectMaGuangaiRecordById(id));
    }

    /**
     * 新增灌溉记录
     */
    @PreAuthorize("@ss.hasPermi('waterele:guangaiRecord:add')")
    @PostMapping
    @ApiOperation("新增灌溉记录")
    public AjaxResult add(@RequestBody MaGuangaiRecord maGuangaiRecord)
    {
        return toAjax(maGuangaiRecordService.insertMaGuangaiRecord(maGuangaiRecord));
    }

    /**
     * 修改灌溉记录
     */
    @PreAuthorize("@ss.hasPermi('waterele:guangaiRecord:edit')")
    @PutMapping
    @ApiOperation("修改灌溉记录")
    public AjaxResult edit(@RequestBody MaGuangaiRecord maGuangaiRecord)
    {
        return toAjax(maGuangaiRecordService.updateMaGuangaiRecord(maGuangaiRecord));
    }

    /**
     * 删除灌溉记录
     */
    @PreAuthorize("@ss.hasPermi('waterele:guangaiRecord:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除灌溉记录")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(maGuangaiRecordService.deleteMaGuangaiRecordByIds(ids));
    }
}
